OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migración en curso. Por favor, espere hasta que la migración esté finalizada.",
    "Migration started …" : "Migración iniciada...",
    "Saved" : "Guardado",
    "Not saved" : "No guardado",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Private" : "Privado",
    "Don't synchronize to servers" : "No sincronizar con servidores",
    "Trusted" : "De confianza",
    "Only synchronize to trusted servers" : "Sincronizar solo con servidores de confianza",
    "Public" : "Público",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y con la libreta de direcciones global y pública",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando…",
    "Unable to change password" : "No se ha podido cambiar la contraseña",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña normal",
    "Good password" : "Contraseña buena",
    "Strong password" : "Contraseña muy buena",
    "An error occurred while changing your language. Please reload the page and try again." : "Ha ocurrido un error al cambiar tu idioma. Por favor, recarga la página y vuelve a intentarlo.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Ha ocurrido un error al cambiar tu región. Por favor, recarga la página y vuelve a intentarlo.",
    "Select a profile picture" : "Seleccionar una imagen de perfil",
    "Week starts on {fdow}" : "La semana empieza el {fdow}",
    "Groups" : "Grupos",
    "Group list is empty" : "La lista de grupos está vacía",
    "Unable to retrieve the group list" : "No se ha podido recuperar la lista de grupos.",
    "{actor} added you to group {group}" : "{actor} te ha añadido al grupo {group}",
    "You added {user} to group {group}" : "Has añadido a {user} al grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} ha añadido a {user} al grupo {group}",
    "An administrator added you to group {group}" : "Un administrador te ha añadido al grupo {group}",
    "An administrator added {user} to group {group}" : "Un administrador ha añadido a {user} al grupo {group}",
    "{actor} removed you from group {group}" : "{actor} te ha eliminado del grupo {group}",
    "You removed {user} from group {group}" : "Has eliminado a {user} del grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} ha eliminado a {user} del grupo {group}",
    "An administrator removed you from group {group}" : "Un administrador te ha eliminado del grupo {group}",
    "An administrator removed {user} from group {group}" : "Un administrador ha eliminado a {user} del grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Se han modificado tus <strong>pertenencias a grupos</strong>.",
    "{actor} changed your password" : "{actor} cambió tu contraseña",
    "You changed your password" : "Has cambiado tu contraseña",
    "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un administrador",
    "Your password was reset" : "Su contraseña ha sido reiniciada.",
    "{actor} changed your email address" : "{actor} cambió tu dirección de correo electrónico",
    "You changed your email address" : "Has cambiado tu cuenta de correo",
    "Your email address was changed by an administrator" : "Tu cuenta de correo ha sido cambiada por un administrador",
    "You created app password \"{token}\"" : "Has creado la contraseña de app \"{token}\"",
    "You deleted app password \"{token}\"" : "Has eliminado la contrasña de app \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Has renombrado la contrasena de app \"{token}\" a \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Has concedido acceso al sistema de archivos a la contraseña de app \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Has revocado el acceso al sistema de archivos a la contraseña de app \"{token}\"",
    "Security" : "Seguridad",
    "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión usando la verificación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "El intento de inicio de sesión usando la autenticación en dos pasos (%1$s) ha fallado",
    "Remote wipe was started on %1$s" : "El borrado remoto se inició en %1$s",
    "Remote wipe has finished on %1$s" : "El borrado remoto finalizó en %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>dirección de correo</strong> fue modificada",
    "Couldn't remove app." : "No se ha podido eliminar la aplicación.",
    "Couldn't update app." : "No se ha podido actualizar la aplicación.",
    "Wrong password" : "Contraseña incorrecta",
    "No user supplied" : "No se especificó un usuario",
    "Authentication error" : "Error de autenticación",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor, asigna una contraseña de recuperación del administrador; si no lo haces, se perderán todos los datos de los usuarios.",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor comprueba la contraseña e inténtalo de nuevo.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "El sistema no permite cambiar la contraseña, pero la clave de cifrado ha sido actualizada.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando y actualizando aplicaciones a través de la tienda de aplicaciones o de la nube compartida federada",
    "Federated Cloud Sharing" : "Compartido en Nube Federada",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL está usando una versión desactualizada %1$s (%2$s). Por favor, actualiza tu sistema operativo o funciones como %3$s no funcionarán de forma fiable.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "No se puede determinar si la vdersión TLS de cURL está anticuada o no debido a que ocurrió un error durante la consulta HTTPS contra https://nextcloud.com. Por favor compruebe el archivo de registro de nexcloud para más detalles.",
    "Invalid SMTP password." : "Contraseña SMTP inválida",
    "Email setting test" : "Prueba de configuración de correo",
    "Well done, %s!" : "¡Bien hecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si recibes este correo, la configuración de correo parece ser correcta.",
    "Email could not be sent. Check your mail server log" : "No se ha podido enviar el correo. Compruebe el registro del servidor de correo",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ha ocurrido  un problema al enviar el mensaje de correo electrónico. Revisa tu configuración. (Error: %s)",
    "You need to set your user email before being able to send test emails." : "Tienes que configurar tu dirección de correo electrónico antes de poder enviar mensajes de prueba.",
    "Invalid mail address" : "Dirección de correo no válido",
    "Settings saved" : "Ajustes guardados",
    "Unable to change full name" : "No se puede cambiar el nombre completo",
    "Unable to change email address" : "No se pudo cambiar la dirección de correo",
    "Unable to set invalid phone number" : "No se pudo registrar un número de teléfono incorrecto",
    "Some account data was invalid" : "Algunos datos de la cuenta no son correctos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para verificar tu cuenta de Twitter, escribe el siguiente tuit en Twitter (por favor, asegúrate de escribirlo sin saltos de línea):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para verificar tu sitio web, guarda el siguiente contenido en la raíz de la web en '.well-known/CloudIdVerificationCode.txt' (por favor, asegúrate de que el texto completo está en una línea):",
    "%1$s changed your password on %2$s." : "%1$s cambió su contraseña en %2$s.",
    "Your password on %s was changed." : "Su contraseña en %s fue cambiada.",
    "Your password on %s was reset by an administrator." : "Su contraseña en %s fue restaurada por un administrador.",
    "Your password on %s was reset." : "Su contraseña en %s ha sido reiniciada.",
    "Password for %1$s changed on %2$s" : "Contraseña para %1$s cambiada en %2$s",
    "Password changed for %s" : "Contraseña cambiada por %s",
    "If you did not request this, please contact an administrator." : "Si no has solicitado esto, por favor, ponte en contacto con el administrador.",
    "Your email address on %s was changed." : "Su dirección de correo electrónico en %s fue cambiada.",
    "Your email address on %s was changed by an administrator." : "Su dirección de correo electrónico en %s fue cambiada por un administrador.",
    "Email address for %1$s changed on %2$s" : "Dirección de correo electrónico para %1$s cambiada en %2$s",
    "Email address changed for %s" : "Dirección de correo eletrónico cambiada para %s",
    "The new email address is %s" : "La nueva direción de correo eletrónica es %s",
    "Your %s account was created" : "Se ha creado su cuenta de %s",
    "Welcome aboard" : "Bienvenido a bordo",
    "Welcome aboard %s" : "Bienvenido a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenido a tu cuenta de %s, puedes añadir, proteger y compartir tus datos.",
    "Your username is: %s" : "Su nombre de usuario es: %s",
    "Set your password" : "Establezca su contraseña",
    "Go to %s" : "Vaya a %s",
    "Install Client" : "Instalar cliente",
    "Logged in user must be a subadmin" : "El usuario registrado debe ser un subadministrador",
    "Apps" : "Apps",
    "Settings" : "Ajustes",
    "Personal" : "Personal",
    "Administration" : "Administración",
    "Additional settings" : "Configuración adicional",
    "Groupware" : "Groupware",
    "Overview" : "Vista general",
    "Basic settings" : "Ajustes básicos",
    "Sharing" : "Compartir",
    "Personal info" : "Información personal",
    "Mobile & desktop" : "Móvil y escritorio",
    "Create" : "Crear",
    "Change" : "Cambiar",
    "Delete" : "Eliminar",
    "Reshare" : "Volver a compartir",
    "Unlimited" : "Ilimitado",
    "Verifying" : "Verificar",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Está pendiente una tarea en segundo plano que comprueba por el usuario los certificados SSL importados. Por favor, revisalo más tarde.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hay algunos certificados SSL importados por el usuario que ya no se utilizan con Nextcloud 21. Pueden ser importados con la línea de comandos a través del comando \"occ security:certificates:import\". Sus rutas dentro del directorio de datos se muestran a continuación.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "El antiguo formato de cifrado en el lado del servidor está activado. Recomendamos deshabilitar esto.",
    "Nextcloud settings" : "Ajustes de Nextcloud",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "La verificación en dos pasos se puede aplicar para todos los usuarios y grupos específicos. Si no tienen configurado un proveedor de dos pasos, no podrán iniciar sesión en el sistema.",
    "Enforce two-factor authentication" : "Imponer verificación en dos pasos",
    "Limit to groups" : "Límite para grupos",
    "Enforcement of two-factor authentication can be set for certain groups only." : "La obligatoriedad de la autenticación de dos pasos puede establecerse solo para ciertos grupos.",
    "Two-factor authentication is enforced for all members of the following groups." : "La autenticación de dos pasos es obligatoria para todos los miembros de los siguientes grupos.",
    "Enforced groups" : "Grupos obligados",
    "Two-factor authentication is not enforced for members of the following groups." : "La autenticación de dos pasos no es obligatoria para los miembros de los siguientes grupos.",
    "Excluded groups" : "Grupos excluidos",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cuando los grupos se seleccionan/excluyen, usan la siguiente lógica para determinar si un usuario tiene obligada la 2FA: si no hay grupos seleccionados, 2FA está activa para todos excepto los miembros de los grupos excluidos. Si hay grupos seleccionados, 2FA está activa para todos los miembros de estos. Si un usuaro está a la vez en un grupo seleccionado y otro excluido, el seleccionado tiene preferencia y se obliga la 2FA.",
    "Save changes" : "Guardar cambios",
    "All" : "Todos",
    "Limit app usage to groups" : "Limitar uso de apps a grupos",
    "No results" : "No hay resultados",
    "Update to {version}" : "Actualizar a {version}",
    "Remove" : "Eliminar",
    "Disable" : "Desactivar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app no tiene una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app no tiene una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede instalarse porque las siguientes dependencias no están cumplimentadas:",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visite el sitio web",
    "Report a bug" : "Notificar un error",
    "User documentation" : "Documentación de usuario",
    "Admin documentation" : "Documentación de administrador",
    "Developer documentation" : "Documentación de desarrollador",
    "This app is supported via your current Nextcloud subscription." : "Esta App está soportada a través de su suscripción actual de Nexcloud.",
    "Supported" : "Soportada",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las apps destacadas están desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad central y están listas para usarlas en producción.",
    "Featured" : "Destacadas",
    "Update to {update}" : "Actualizar a {update}",
    "Update all" : "Actualizar todo",
    "Results from other categories" : "Resultados de otras categorías",
    "No apps found for your version" : "No se han encontrado aplicaciones para su versión",
    "Disable all" : "Deshabilitar todos",
    "Enable all" : "Activar todas",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app tiene una actualización disponible.","%n apps tienen una actualización disponible."],
    "Marked for remote wipe" : "Marcado para borrado remoto",
    "Device settings" : "Configuración del dispositivo",
    "Allow filesystem access" : "Permitir acceso al sistema de archivos",
    "Rename" : "Renombrar",
    "Revoke" : "Anular",
    "Wipe device" : "Borrar dispositivo",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Anular este token puede evitar el borrado de tu dispositivo si aún no se ha iniciado el borrado.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome para Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "App Nextcloud para iOS",
    "Nextcloud Android app" : "App Nextcloud para Android",
    "Nextcloud Talk for iOS" : "Nextcloud Talk para iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk para Android",
    "Sync client - {os}" : "Cliente de sincronización - {os}",
    "This session" : "Esta sesión",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividad",
    "Devices & sessions" : "Dispositivos y sesiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, móviles y de escritorio actualmente conectados a tu cuenta.",
    "Do you really want to wipe your data from this device?" : "¿Estás seguro de querer borrar tus datos de este dispositivo?",
    "Confirm wipe" : "Confirmar borrado",
    "Error while creating device token" : "Error al crear \"token\" de dispositivo",
    "Error while updating device token scope" : "Error al actualizar el alcance del token de dispositivo",
    "Error while updating device token name" : "Error al actualizar el nombre del token de dispositivo",
    "Error while deleting the token" : "Error al eliminar el \"token\"",
    "Error while wiping the device with the token" : "Error al borrar el dispositivo con el token",
    "App name" : "Nombre de la app",
    "Create new app password" : "Crear nueva contraseña de app",
    "Use the credentials below to configure your app or device." : "Use las siguientes credenciales para configurar su app o dispositivo.",
    "For security reasons this password will only be shown once." : "Para seguridad, esta contraseña será mostrada solamente una vez.",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Done" : "Hecho",
    "Show QR code for mobile apps" : "Mostrar código QR para apps móviles",
    "Copied!" : "¡Copiado!",
    "Copy" : "Copiar",
    "Could not copy app password. Please copy it manually." : "No se ha podido copiar la contraseña de app. Por favor, cópiala manualmente.",
    "You do not have permissions to see the details of this user" : "No tienes permisos para ver los detalles de este usuario",
    "Add new password" : " Añadir nueva contraseña",
    "Add new email address" : "Añadir nueva dirección de correo electrónico",
    "Add user in group" : "Añadir usuario en grupo",
    "Set user as admin for" : "Marcar usuario como administrador para",
    "Select user quota" : "Seleccionar cuota de usuario",
    "No language set" : "No se ha marcado idioma",
    "Delete user" : "Eliminar usuario",
    "Wipe all devices" : "Borrar todos los dispositivos",
    "Disable user" : "Inhabilitar usuario",
    "Enable user" : "Habilitar usuario",
    "Resend welcome email" : "Volver a enviar correo de bienvenida",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o dejar la organización, esto puede eliminar remotamente los datos de Nextcloud de todos los dispositivos asociados con {userid}. Nota: sólo funciona si los dispositivos están conectados a Internet.",
    "Remote wipe of devices" : "Eliminación remota de dispositivos",
    "Wipe {userid}'s devices" : "Eliminar dispositivos de {userid}",
    "Cancel" : "Cancelar",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eliminar completamente la cuenta de {userid}, incluyendo todos sus archivos personales, datos de las apps, etc.",
    "Account deletion" : "Eliminación de la cuenta",
    "Delete {userid}'s account" : "Eliminar cuentas de {userid}",
    "Welcome mail sent!" : "¡Correo de bienvenida enviado!",
    "Edit User" : "Editar usuario",
    "Toggle user actions menu" : "Alternar el menú de acciones del usuario",
    "{size} used" : "{size} usados",
    "Will be autogenerated" : "Se generará de forma automática",
    "Display name" : "Nombre para mostrar",
    "Email" : "Correo electrónico",
    "Default language" : "Idioma predeterminado",
    "Add a new user" : "Añadir nuevo usuario",
    "Close" : "Cerrar",
    "Group admin for" : "Administrador de grupo para",
    "Quota" : "Espacio asignado",
    "Language" : "Idioma",
    "User backend" : "Motor de usuario",
    "Storage location" : "Ubicación de los datos",
    "Last login" : "Último inicio de sesión",
    "No users in here" : "No hay usuarios aquí",
    "Default quota" : "Espacio predefinido",
    "Common languages" : "Idiomas habituales",
    "All languages" : "Todos los idiomas",
    "Password change is disabled because the master key is disabled" : "El cambio de contraseña está desactivado porque la clave maestra está desactivada",
    "Passwordless authentication requires a secure connection." : "La autenticación sin contraseña requiere una conexión segura.",
    "Add WebAuthn device" : "Añadir dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autorice a su dispositivo WebAuthn, por favor.",
    "Name your device" : "Nombre de tu dispositivo",
    "Add" : "Añadir",
    "Adding your device …" : "Añadiendo tu dispositivo...",
    "Server error while trying to add WebAuthn device" : "Error del servidor al intentar añadir el dispositivo WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Error del servidor al intentar completar el registro del dispositivo WebAuthn",
    "Unnamed device" : "Dispositivo sin nombre",
    "Passwordless Authentication" : "Autenticación sin contraseña",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configure su cuenta para autenticarla sin contraseña siguiendo el estándar FIDO2.",
    "No devices configured." : "No hay dispositivos configurados.",
    "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados en su cuenta:",
    "Your browser does not support WebAuthn." : "Tu navegador no soporta WebAuthn.",
    "Your apps" : "Tus apps",
    "Active apps" : "Apps activas",
    "Disabled apps" : "Apps deshabilitadas",
    "Updates" : "Actualizaciones",
    "App bundles" : "Lotes de apps",
    "Featured apps" : "Apps destacadas",
    "{license}-licensed" : "licenciado bajo {license}",
    "Details" : "Detalles",
    "Changelog" : "Historial de cambios",
    "by {author}\n{license}" : "por {author}\n{license}",
    "New user" : "Nuevo usuario",
    "Enter group name" : "Introduce el nombre del grupo",
    "Add group" : "Añadir grupo",
    "Everyone" : "Todos",
    "Admins" : "Administradores",
    "Disabled users" : "Usuarios inhabilitados",
    "Remove group" : "Eliminar grupo",
    "Default quota:" : "Espacio por defecto:",
    "Select default quota" : "Seleccionar espacio por defecto",
    "Show Languages" : "Mostrar idiomas",
    "Show last login" : "Mostrar último inicio de sesión",
    "Show user backend" : "Mostrar motor de usuario",
    "Show storage path" : "Mostrar ruta de almacenamiento",
    "Send email to new user" : "Enviar correo al usuario nuevo",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Vas a eliminar el grupo {group}. Los usuarios NO serán eliminados.",
    "Please confirm the group removal " : "Por favor, confirma la eliminación del grupo",
    "Download and enable" : "Descargar y activar",
    "Enable" : "Activar",
    "Enable untested app" : "Activar app no probada",
    "The app will be downloaded from the app store" : "La app va a ser descargada de una tienda de aplicaciones",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta app no está marcada como compatible con tu versión de Nextcloud. Si continúas podrás instalar la app, pero ten en cuenta que podría no funcionar según lo esperado.",
    "Never" : "Nunca",
    "An error occured during the request. Unable to proceed." : "Ha ocurrido un error durante la petición. No se puede continuar.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La app ha sido activada pero tiene que actualizarse. Serás redirigido a la página de actualización en 5 segundos.",
    "App update" : "Actualización de la aplicación",
    "Error: This app can not be enabled because it makes the server unstable" : "Error: Esta app no se puede activar porque desestabiliza el servidor",
    "Administrator documentation" : "Documentación del adminsitrador",
    "Documentation" : "Documentación",
    "Forum" : "Foro",
    "None" : "Ninguno",
    "Login" : "Iniciar sesión",
    "Plain" : "Plano",
    "NT LAN Manager" : "Gestor de NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor de correo electrónico",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante configurar este servidor para que pueda enviar correos, por ejemplo para cambios de contraseñas y notificaciones.",
    "Send mode" : "Modo de envío",
    "Encryption" : "Cifrado",
    "Sendmail mode" : "Modo Sendmail",
    "From address" : "Desde la dirección",
    "mail" : "correo electrónico",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Se necesita autenticación",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nombre de usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Test email settings" : "Probar configuración del correo electrónico",
    "Send email" : "Enviar mensaje",
    "Security & setup warnings" : "Avisos de seguridad y configuración",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de tu instancia que todo esté correctamente configurado. Para ayudarte con ello estamos haciendo algunas comprobaciones automáticas. Para más información, por favor comprueba la documentación enlazada.",
    "All checks passed." : "Ha pasado todos los controles",
    "There are some errors regarding your setup." : "Hay varios errores relativos a su configuración.",
    "There are some warnings regarding your setup." : "Hay varios avisos relativos a su configuración.",
    "Checking for system and security issues." : "Comprobando problemas en el sistema y de seguridad.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, vuelve a consultar las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a>, y comprueba posibles errores y advertencias en el <a href=\"%2$s\">registro</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Compruebe la seguridad de su Nextcloud mediante <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nuestro escaneo de seguridad ↗</a>.",
    "Version" : "Versión",
    "Two-Factor Authentication" : "Verificación en dos pasos",
    "Server-side encryption" : "Cifrado en el servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "El cifrado en el lado del servidor hace posible cifrar archivos que se suben a este servidor. Esto trae consigo limitaciones como una ralentización en su funcionamiento, así que activa esto solo si es necesario.",
    "Enable server-side encryption" : "Habilitar cifrado en el servidor",
    "Please read carefully before activating server-side encryption: " : "Por favor lea cuidadosamente antes de activar el cifrado del lado del servidor.",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que el cifrado está habilitado, todos los archivos subidos al servidor desde ese punto en adelante se cifrarán en reposo en el servidor. Sólo será posible desactivar el cifrado en una fecha posterior si el módulo de cifrado activado soporta esa función, y todas las condiciones (por ejemplo, el establecimiento de una clave de recuperación) se cumpen.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "El cifrado no garantiza por sí solo la seguridad del sistema. Por favor, vea la documentación para más información sobre cómo funciona la app de cifrado y los casos de uso soportados.",
    "Be aware that encryption always increases the file size." : "Tenga presente que la encripción siempre incrementa el tamaño del archivo.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es bueno crear copias de seguridad de sus datos, en el caso del cifrado, asegúrese de tener una copia de seguridad de las claves de cifrado junto con sus datos.",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final. ¿Realmente quiere activar el cifrado?",
    "Enable encryption" : "Habilitar cifrado",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado el modulo de cifrado. Por favor habilite un modulo de cifrado en el menú de aplicaciones.",
    "Select default encryption module:" : "Seleccione el módulo de cifrado por defecto:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesita migrar sus claves de cifrado provenientes del antiguo sistema (ownCloud <= 8.0) al nuevo. Por favor habilite el \"Módulo de cifrado por defecto\" y ejecute 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Se necesita migrar las claves de cifrado del antiguo sistema (ownCloud <= 8.0) al nuevo sistema.",
    "Start migration" : "Iniciar migración",
    "Background jobs" : "Trabajos en segundo plano",
    "Last job execution ran %s. Something seems wrong." : "La última ejecución de un trabajo fue %s. Algo parece ir mal.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Algunos trabajos no se han ejecutado desde %s. Por favor, considere aumentar la frecuencia de ejecución.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Algunos trabajajos no se ejecutaron desde %s. Por favor, considere cambiar al sistema 'cron'.",
    "Last job ran %s." : "El último trabajo se ejecutó %s.",
    "Background job didn’t run yet!" : "¡El trabajo en segundo plano no se ha ejecutado todavía!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para un rendimiento óptimo es importante configurar correctamente los procesos en segundo plano. Para las instancias más grandes la configuración recomendada es 'Cron'. Por favor, lea la documentación para más información.",
    "Pick background job setting" : "Escoge la configuración de las tareas en segundo plano",
    "Execute one task with each page loaded." : "Ejecutar una tarea con cada página cargada.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php está registrado en un servicio de web cron para llamar a cron.php cada 5 minutos por HTTP.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Usa el servicio cron del sistema para llamar al archivo cron.php cada 5 minutos.",
    "The cron.php needs to be executed by the system user \"%s\"." : "El archivo cron.php debe ser ejecutado por el usuario de sistema \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Necesitas la extensión PHP POSIX para lanzar esto. Mira la {linkstart}documentación de PHP{linkend} para más detalles.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador puedes ajustar el comportamiento de compartir. Por favor, lea la documentación para más información.",
    "Allow apps to use the Share API" : "Permitir a las aplicaciones utilizar la API de Compartir",
    "Set default expiration date for shares" : "Establecer fecha de caducidad predeterminada para recursos compartidos",
    "Expire after " : "Caduca tras",
    "days" : "días",
    "Enforce expiration date" : "Imponer fecha de caducidad",
    "Allow users to share via link" : "Permite a los usuarios compartir por medio de enlaces",
    "Allow public uploads" : "Permitir subidas públicas",
    "Always ask for a password" : "Pedir siempre la contraseña",
    "Enforce password protection" : "Forzar la protección por contraseña.",
    "Set default expiration date for link shares" : "Establecer fecha de caducidad predeterminada para enlaces compartidos",
    "Allow resharing" : "Permitir que se vuelva a compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a compartir solo con los usuarios de sus grupos",
    "Exclude groups from sharing" : "Excluye grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir contenidos compartidos, pero no podrán iniciarlos.",
    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Permitir autocompletado del nombre de usuario en el diálogo de compartir (si esto está desactivado, hay que introducir completos el nombre de usuario completo o la dirección de correo)",
    "Restrict username autocompletion to users within the same groups" : "Limitar autocompletar de usuarios solo para los usuarios dentro del mismo grupo",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostrar texto de aviso en la página de subida de enlace público (solo se muestra cuando la lista de archivos está oculta)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de subida de enlace público cuando la lista de archivos esté oculta.",
    "Default share permissions" : "Permisos para compartir por defecto",
    "Reasons to use Nextcloud in your organization" : "Razones para usar Nextcloud en su organización",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la {communityopen}comunidad Nextcloud{linkclose}, el {githubopen}código fuente{linkclose} está bajo la licencia  {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Da a Me gusta en nuestra página de Facebook",
    "Follow us on Twitter" : "Síguenos en Twitter",
    "Follow us on Mastodon" : "Síguenos en Mastodon",
    "Check out our blog" : "Lee nuestro blog",
    "Subscribe to our newsletter" : "Suscríbete a nuestro boletín",
    "Profile picture" : "Foto de perfil",
    "Upload new" : "Subir nueva",
    "Select from Files" : "Seleccionar desde Archivos",
    "Remove image" : "Borrar imagen",
    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
    "Picture provided by original account" : "Imagen provista por la cuenta original",
    "Choose as profile picture" : "Seleccionar como imagen de perfil",
    "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
    "You are using <strong>%s</strong>" : "Estás usando <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Estás usando <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
    "Full name" : "Nombre completo",
    "No display name set" : "No se ha establecido ningún nombre para mostrar",
    "Your email address" : "Su dirección de correo",
    "No email address set" : "No hay establecida ninguna dirección de correo",
    "For password reset and notifications" : "Para notificaciones y cambio de contraseña",
    "Phone number" : "Número de teléfono",
    "Your phone number" : "Su número de teléfono",
    "Address" : "Dirección",
    "Your postal address" : "Su dirección física",
    "Website" : "Sitio web",
    "It can take up to 24 hours before the account is displayed as verified." : "Puede tardar hasta 24 horas que la cuenta aparezca como verificada.",
    "Link https://…" : "Enlace https://...",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Usuario de Twitter @...",
    "Help translate" : "Ayúdanos a traducir",
    "Locale" : "Región",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Change password" : "Cambiar contraseña",
    "Use a second factor besides your password to increase security for your account." : "Usa un segundo paso además de tu contraseña para incrementar la seguridad de tu cuenta. ",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utiliza aplicaciones de terceras partes para conectarse a Nextcloud, por favor compruebe que crea y configura una contraseña de app para cada una antes de activar el factor de autentificación de dos pasos.",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ha ocurrido un error. Por favor, cargue un certificado PEM codificado en ASCII.",
    "Valid until {date}" : "Válido hasta {date}",
    "Local" : "Local",
    "Only visible to local users" : "Visible solo a usuarios locales",
    "Only visible to you" : "Visible sólo para ti",
    "Contacts" : "Contactos",
    "Visible to local users and to trusted servers" : "Visible para usuarios locales y servidores de confianza",
    "Will be synced to a global and public address book" : "Se sincronizará a una libreta de direcciones pública y global",
    "by" : "por",
    "{counter} apps have an update available" : "{counter} apps tienen una actualización disponible",
    "SSL Root Certificates" : "Certificados raíz SSL  ",
    "Common Name" : "Nombre común",
    "Valid until" : "Válido hasta",
    "Issued By" : "Emitido por",
    "Valid until %s" : "Válido hasta %s",
    "Import root certificate" : "Importar certificado raíz",
    "Execute one task with each page loaded" : "Ejecutar una tarea con cada página cargada",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Permitir autocompletado del nombre de usuario en el diálogo de compartir. Si se desactiva, se necesitará introducir el nombre de usuario completo o la dirección de correo electrónico.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Mostrar texto de descargo de responsabilidad en la página de subida con el enlace público. (Sólo se muestra cuando la lista de archivos está oculta.)"
},
"nplurals=2; plural=(n != 1);");
